@@ -108,6 +108,12 @@ prettify_V8 <- function(contents = NA, language = NA, tabSize = NULL){
     )
   }
 
+  addsfile <- function(file){
+    system.file(
+      "V8adds", file, package = "prettifyAddins"
+    )
+  }
+
   ctx <- V8::v8(console = FALSE)
   tryCatch({
     ctx$source(jsfile("standalone.js"))
@@ -118,6 +124,8 @@ prettify_V8 <- function(contents = NA, language = NA, tabSize = NULL){
     )
   })
 
+  ctx$source(addsfile("trimEnd.js"))
+
   js <- switch(
     parser,
     babel = "parser-babel.js",
